<!-- Badges -->

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/9c0158b110a54cce953d319d5f5b438d)](https://www.codacy.com/gh/Hepheir/BOJ-Offline-Judge/dashboard?utm_source=github.com&utm_medium=referral&utm_content=Hepheir/BOJ-Offline-Judge&utm_campaign=Badge_Grade)
[![Shields Badge - PyPI/version](https://img.shields.io/pypi/v/boj)](https://pypi.org/project/boj/)
[![Shields Badge - PyPI/license](https://img.shields.io/pypi/l/boj)](https://pypi.org/project/boj/)
[![Shields Badge - PyPI/downloads](https://img.shields.io/pypi/dm/boj)](https://pypi.org/project/boj/)
[![Shields Badge - PyPI/status](https://img.shields.io/pypi/status/boj)](https://pypi.org/project/boj/)
[![GitHub/issues](https://img.shields.io/github/issues/Hepheir/BOJ-Offline-Judge.svg)](https://github.com/Hepheir/BOJ-Offline-Judge/issues)

# BOJ Offline Judge

## 프로젝트 설명

### BOJ Offline Judge란?

BOJ-Offline-Judge는 백준 온라인 저지를 CLI, 혹은 Python 스크립트를 통해 이용 하기 위해 제작한 API 입니다.

BOJ는 간단한 JSON혹은 Python의 딕셔너리 형태의 문제 데이터를 제공합니다.

-   [프로젝트 소개 보기](/docs/README.md)
-   [변경 이력 보기](/docs/CHANGELOG.md)
-   [프로젝트에 기여하기](/docs/CONTRIBUTING.md)

## 프로젝트 목적

본 프로젝트를 통해 성취하고자 하는 바는 다음과 같습니다.

-   Python 언어 어휘력 증가

-   Git을 능숙하게 사용하기

-   GitHub를 능숙하게 사용하기
    <sup>Issue, PullRequest, ...</sup>

-   GitFlow를 이용한 작업에 익숙해지기
    <sup>[atlassian.com](https://www.atlassian.com/git/tutorials/comparing-workflows/gitflow-workflow)</sup>

-   PyPI에 패키지 배포하기
    <sup>[pypi.org](https://pypi.org/project/boj/)</sup>

-   Sementic Versioning 사용해보기
    <sup>[semver.org](https://semver.org/lang/ko/)</sup>

-   Google Python Style Guide에 익숙해지기
    <sup>[pyguide](https://google.github.io/styleguide/pyguide.html)</sup>

-   Remark (Markdown Style Guide)에 익숙해지기

-   Code Quality 관리하기
    <sup>[Codacy](https://app.codacy.com/gh/Hepheir/BOJ-Offline-Judge/dashboard?utm_source=github.com&utm_medium=referral&utm_content=Hepheir/BOJ-Offline-Judge&utm_campaign=Badge_Grade)</sup>

-   Python 패키지 관리 시스템 `poetry` 사용해보기
      <sup>[poetry](https://python-poetry.org/)</sup>

-   `pytest` 모듈을 이용한 유닛테스트 관리
      <sup>[pytest](https://docs.pytest.org//)</sup>
